% Wireless Communication - BER Performance Analysis for BPSK

% Parameters
SNR_dB = 0:2:12; % Signal-to-Noise Ratio (dB)
numBits = 1e6;   % Number of bits to be transmitted

% Generate random binary data
data = randi([0 1], 1, numBits);

ber = zeros(size(SNR_dB));

for i = 1:length(SNR_dB)
    % BPSK modulation
    modulatedSignal = 2 * data - 1;

    % Add AWGN
    noise = sqrt(0.5 / 10^(SNR_dB(i) / 10)) * randn(1, numBits);
    receivedSignal = modulatedSignal + noise;

    % BPSK demodulation
    demodulatedSignal = sign(receivedSignal);

    % Calculate Bit Error Rate (BER)
    ber(i) = sum(data ~= (demodulatedSignal + 1) / 2) / numBits;
end
% Plot BER vs. SNR
figure;
semilogy(SNR_dB, ber, 'o-', 'LineWidth', 2);
grid on;
title('BER Performance Analysis for BPSK');
xlabel('SNR (dB)');
ylabel('Bit Error Rate (BER)');
